"""
Add task to glider configuration.

    Usage:

        add-task glider task

    or

        python add_task.py path/to/config/file glider task
"""

import sys
import errno
import lockfile as lf
import ConfigParser as cp

valid_tasks = {"alert":
                  {"description":
                       "Print a surface message on the autopilot console.",
                   "priority": 0,
                  },
               "bearing":
                  {"description":
                       "Generate a goto list based on a bearing.",
                   "priority": 1,
                  },
               "target":
                  {"description":
                       "Generate a goto list based on a target waypoint.",
                   "priority": 2,
                  },
               "track":
                  {"description":
                       "Email a Nobletec file to a subscriber list.",
                   "priority": 3,
                  },
              }

def _usage():
    tasks = valid_tasks.items()
    tasks.sort(cmp=lambda x, y: cmp(x[1]["priority"],
                                    y[1]["priority"]))
    print __doc__
    print "    Valid tasks (in order of priority of service):"
    print "\n       ",
    print "\n        ".join(["%s: %s" % (k, v["description"])
                             for k, v in tasks])
    print
    return

if __name__ == "__main__":
    num_args = len(sys.argv) - 1
    if num_args != 3:
        _usage()
    else:
        cfg_path = sys.argv[1]
        glider = sys.argv[2].lower()
        task = sys.argv[3].lower()
        if task not in valid_tasks:
            _usage()
        else:
            report = {"glider": glider,
                      "path": cfg_path,
                      "task": task,
                     }
            try:
                lock = lf.FileLock(cfg_path)
                lock.acquire(5)
            except lf.LockTimeout:
                lock.break_lock()
                lock.acquire(0)
            config = cp.SafeConfigParser()
            try:
                with open(cfg_path) as handle:
                    config.readfp(handle)
            except IOError as e:
                if e.errno == errno.ENOENT:
                    print "Glider {glider} does not exist in {path}.". \
                          format(**report)
                else:
                    raise
            else:
                try:
                    tasks = config.get(glider, "tasks").split()
                    if "bearing" in tasks and task == "target":
                        tasks.remove("bearing")
                        print "The bearing task for glider {glider} " \
                              "deleted from {path}.". \
                              format(**report)
                    elif "target" in tasks and task == "bearing":
                        tasks.remove("target")
                        print "The target task for glider {glider} " \
                              "deleted from {path}.". \
                              format(**report)
                except cp.NoOptionError:
                    tasks = []
                except cp.NoSectionError:
                    config.add_section(glider)
                    print "Glider {glider} added to {path}.".format(**report)
                    tasks = []
                if task in tasks:
                    print "The {task} task for glider {glider} " \
                          "already exists in {path}.". \
                          format(**report)
                else:
                    tasks.append(task)
                    tasks.sort(cmp=lambda x, y:
                                       cmp(valid_tasks[x]["priority"],
                                           valid_tasks[y]["priority"]))
                    config.set(glider, "tasks", " ".join(tasks))
                    with open(cfg_path, "w") as handle:
                        config.write(handle)
                    print "The {task} task for glider {glider} " \
                          "added to {path}.". \
                          format(**report)
            finally:
                lock.release()
