"""
Delete task from glider configuration.

    Usage:

        delete-task glider task

    or

        python delete_task.py path/to/config/file glider task
"""

import sys
import errno
import lockfile as lf
import ConfigParser as cp

if __name__ == "__main__":
    num_args = len(sys.argv) - 1
    if num_args != 3:
        print __doc__
    else:
        cfg_path = sys.argv[1]
        glider = sys.argv[2].lower()
        task = sys.argv[3].lower()
        report = {"glider": glider,
                  "path": cfg_path,
                  "task": task,
                     }
        try:
            lock = lf.FileLock(cfg_path)
            lock.acquire(5)
        except lf.LockTimeout:
            lock.break_lock()
            lock.acquire(0)
        config = cp.SafeConfigParser()
        try:
            with open(cfg_path) as handle:
                config.readfp(handle)
        except IOError as e:
            if e.errno == errno.ENOENT:
                print "Glider {glider} does not exist in {path}.". \
                      format(**report)
            else:
                raise
        else:
            try:
                tasks = config.get(glider, "tasks").split()
            except cp.NoOptionError:
                print "The {task} task for glider {glider} " \
                      "does not exist in {path}.". \
                      format(**report)
            except cp.NoSectionError:
                print "Glider {glider} does not exist in {path}.". \
                      format(**report)
            else:
                if task not in tasks:
                    print "The {task} task for glider {glider} " \
                          "does not exist in {path}.". \
                          format(**report)
                else:
                    tasks.remove(task)
                    config.set(glider, "tasks", " ".join(tasks))
                    with open(cfg_path, "w") as handle:
                        config.write(handle)
                    print "The {task} task for glider {glider} " \
                          "deleted from {path}.". \
                          format(**report)
        finally:
            lock.release()
