"""
List gliders in configuration file.

    Usage:

        list-gliders

    or

        python list_gliders.py path/to/config/file
"""

import sys
import errno
import lockfile as lf
import ConfigParser as cp

if __name__ == "__main__":
    num_args = len(sys.argv) - 1
    if num_args != 1:
        print __doc__
    else:
        cfg_path = sys.argv[1]
        try:
            lock = lf.FileLock(cfg_path)
            lock.acquire(5)
        except lf.LockTimeout:
            lock.break_lock()
            lock.acquire(0)
        config = cp.SafeConfigParser()
        try:
            with open(cfg_path) as handle:
                config.readfp(handle)
        except IOError as e:
            if e.errno == errno.ENOENT:
                print "There are no gliders at this time in {0}.". \
                      format(cfg_path)
            else:
                raise
        else:
            gliders = config.sections()
            if gliders:
                print "\n".join(gliders)
            else:
                print "There are no gliders at this time in {0}.". \
                      format(cfg_path)
        finally:
            lock.release()
