"""
List tasks in glider configuration.

    Usage:

        list-tasks glider

    or

        python list_tasks.py path/to/config/file glider
"""

import sys
import errno
import lockfile as lf
import ConfigParser as cp

if __name__ == "__main__":
    num_args = len(sys.argv) - 1
    if num_args != 2:
        print __doc__
    else:
        cfg_path = sys.argv[1]
        glider = sys.argv[2].lower()
        report = {"glider": glider,
                  "path": cfg_path,
                 }
        try:
            lock = lf.FileLock(cfg_path)
            lock.acquire(5)
        except lf.LockTimeout:
            lock.break_lock()
            lock.acquire(0)
        config = cp.SafeConfigParser()
        try:
            with open(cfg_path) as handle:
                config.readfp(handle)
        except IOError as e:
            if e.errno == errno.ENOENT:
                print "Glider {glider} does not exist in {path}.". \
                      format(**report)
            else:
                raise
        else:
            try:
                tasks = config.get(glider, "tasks").split()
                if tasks:
                    print "\n".join(tasks)
                else:
                    print "No tasks for glider {glider} " \
                          "exist in {path}.". \
                          format(**report)
            except cp.NoOptionError:
                print "No tasks for glider {glider} " \
                      "exist in {path}.". \
                      format(**report)
            except cp.NoSectionError:
                print "Glider {glider} does not exist in {path}.". \
                      format(**report)
        finally:
            lock.release()
